/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
#ifndef _GNOTIFYLIB_H
#define _GNOTIFYLIB_H

#include <sys/socket.h>
#include <netinet/in.h>
#include <string.h>
#include <sys/types.h>
#include <netinet/in.h>
#include <netdb.h>
#include <unistd.h>
#include <arpa/inet.h>
#include <fcntl.h>
#include <stdarg.h>
#include <stdio.h>
#include <stdlib.h>

#define LOCAL "127.0.0.1"

/* SETCFG/GETCFG */
#define X_POSITION "X"
#define Y_POSITION "Y"
#define NOTIFICATION_DELAY "DELAY"
#define PLAY_SOUND "PLAY"
#define ALLOW_NOTIFICATION_MOVING "ALLOWMOVE"
#define ALLOW_HTTP_INFOPAGE "ALLOWHTML"
#define GSTREAMER_SOUND_SINK "SSINK"
#define ALLOW_CONFIGURATION_RELOADING "ALLOWRELOAD"
#define ALLOW_CONFIGURATION_CHANGES "ALLOWCONFCHANGE"
#define SAVE_CONFIGURATION_ON_EXIT "SAVECONFONEXIT"

/* Values */
#define YES "1"
#define NO "0"
#ifndef TRUE
	#define TRUE "1"
#endif
#ifndef FALSE
	#define FALSE "0"
#endif

/*
 * GNotify initializer, this function must be called before every
 * Gnotify-session. It returns the socket-descriptor of the current session or
 * a value < 0 on error 
 */
int gnotify_init(char *host);

/*
 * This function *must* be called to quit a GNotify-session!
 */
void gnotify_quit(int sockhdl);

/*
 * Sending raw commands to the GNotify-server.. use it only if you know
 * what you're doing!
 */
int gnotify_send_raw_string(int sockhdl, char *string, ...);

/*
 * Wait for a server-return-value and return the return-code.
 * E.g.: If the server returns "220 Ok", this function will return
 * '220'.
 */
int gnotify_get_return(int sockhdl);

int gnotify_set_title(int sockhdl, char *string);
int gnotify_set_icon(int sockhdl, char *string);
int gnotify_set_button(int sockhdl, char *string);
int gnotify_set_snd(int sockhdl, char *string);
int gnotify_set_x_position(int sockhdl, char *string);
int gnotify_set_y_position(int sockhdl, char *string);
int gnotify_set_checkbox(int sockhdl, char *string);
int gnotify_notify(int sockhdl, char *string);

/*
 * This function makes GNotify (if the user's configuration allows it)
 * reloading the configuration-file.
 */
int gnotify_reload(int sockhdl);
int gnotify_save_configuration(int sockhdl);
int gnotify_set_configuration(int sockhdl, char *string, char *value);
char *gnotify_get_configuration(int sockhdl, char *string);

#endif
